#include <stdlib.h>
#include <string.h>
#include <math.h>

#include <glib/gi18n.h>

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <X11/Xlib.h>

#include "draw.h"

void
draw_polygon (cairo_t *cr, GdkColor *color, double alpha, BmpPoint points[], gint n_points, gboolean fill)
{
	gint n;
	double r,g,b,a;

 	cairo_set_line_width (cr, 1.0);
	gdk_color_to_rgba (color, &r, &g, &b, &a);

	cairo_move_to (cr, points[0].x, points[0].y);

	for (n = 1; n < n_points; n++)
		cairo_line_to (cr, points[n].x, points[n].y);

	cairo_line_to (cr, points[0].x, points[0].y);
	cairo_set_source_rgba (cr, r, g, b, alpha);

	if (fill)
		cairo_fill (cr);
	else
		cairo_stroke (cr);
}

void
draw_rectangle_simple (cairo_t *cr, GdkColor *color, double alpha, gint x, gint y, gint width, gint height)
{
    double r, g, b, a;

    cairo_rectangle (cr, 
			     x,
		             y,
		 	     width, 
			     height);
    gdk_color_to_rgba (color, &r, &g, &b, &a);
    cairo_set_source_rgba (cr, r, g, b, alpha); 
    cairo_fill (cr);
}

void
draw_rounded_rectangle_pattern (cairo_t *cr, 
					    double xc, 
					    double yc, 
					    double _w, 
					    double _h, 
					    cairo_pattern_t *cr_pattern, 
					    double line_width, 
					    gboolean fill, 
					    gdouble rounding_offset)
{
    cairo_set_line_width (cr, line_width);

    cairo_move_to (cr, xc, yc+rounding_offset*8);

    cairo_curve_to (cr, 	xc,    yc+rounding_offset*8,
				xc+rounding_offset,  yc+rounding_offset,
				xc+rounding_offset*8, yc);

    cairo_line_to (cr, xc+_w-(rounding_offset*8), yc);

    cairo_curve_to (cr, 	xc+_w-(rounding_offset*8), yc,
				xc+_w,   yc+rounding_offset,
				xc+_w,   yc+(rounding_offset*8));
					
    cairo_line_to (cr, xc+_w, yc+_h-(rounding_offset*8));

    cairo_curve_to (cr, 	xc+_w,   yc+_h-(rounding_offset*8),
				xc+_w-rounding_offset, yc+_h-rounding_offset,
				xc+_w-(rounding_offset*8),yc+_h);

    cairo_line_to (cr, xc+(rounding_offset*8), yc+_h);

    cairo_curve_to (cr, 	xc+(rounding_offset*8), yc+_h,
				xc+rounding_offset,   yc+_h-rounding_offset,
				xc,   yc+_h-(rounding_offset*8));
    cairo_close_path (cr);

    cairo_set_source (cr, cr_pattern); 

    if (fill)
	    cairo_fill (cr);
    else
	    cairo_stroke (cr);
}

void
draw_rounded_rectangle (cairo_t *cr, 
				    double xc, 
				    double yc, 
				    double _w, 
				    double _h, 
				    GdkColor *color, 
				    double alpha, 
				    double line_width, 
				    gboolean fill, 
				    gdouble rounding_offset)
{
    double r, g, b, a;

    cairo_set_line_width (cr, line_width);

    cairo_move_to (cr, xc, yc+(rounding_offset*2));

    cairo_curve_to (cr, 	xc, yc+rounding_offset,
				xc, yc,
				xc+rounding_offset, yc);

    cairo_line_to  (cr, xc+_w-(rounding_offset*2), yc);

    cairo_curve_to (cr, xc+_w-rounding_offset, yc,
			xc+_w, yc,
			xc+_w, yc+rounding_offset);

    cairo_line_to (cr,  xc+_w, yc+_h-(rounding_offset*2));

    cairo_curve_to (cr, xc+_w, yc+_h-rounding_offset,
		        xc+_w, yc+_h,
			xc+_w-rounding_offset, yc+_h);

    cairo_line_to (cr, xc+(rounding_offset*2), yc+_h);

    cairo_curve_to (cr, xc+rounding_offset, yc+_h,
			xc, yc+_h,
			xc, yc+_h-rounding_offset);

    cairo_close_path (cr);

    gdk_color_to_rgba (color, &r, &g, &b, &a);
    cairo_set_source_rgba (cr, r, g, b, alpha);

    if (fill)
	    cairo_fill (cr);
    else
	    cairo_stroke (cr);
}

void
gdk_color_to_rgba (GdkColor *color, double *r, double *g, double *b, double *a)
{
  *r = color->red   / 65535.0;
  *g = color->green / 65535.0;
  *b = color->blue  / 65535.0;
  *a = 1;
}
